#
# spec file for package cc65
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cc65
Version:        2.15.0+git.20180312
Release:        1.25
Summary:        Crosscompiler/Crossassembler for 6502 systems
License:        GPL-2.0-only
Group:          Development/Languages/C and C++
URL:            http://cc65.github.io/cc65/
Source:         %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
BuildRequires:  fdupes

%description
A complete cross development package for 65(C)02 systems, including a powerful
macro assembler, a C compiler, linker, librarian and several other tools.

cc65 has C and runtime library support for many of the old 6502 machines,
including the following Commodore machines: VIC20, C16/C116 and Plus/4, C64,
C128, CBM 510 (aka P500), the 600/700 family, newer PET machines (not 2001);
the Apple ][+ and successors; the Atari 8 bit machines; GEOS for the C64, the
C128 and the Apple IIe; the Nintendo Entertainment System (NES); the
Supervision console; the Oric Atmos; the Lynx console.

The libraries are fairly portable, so creating a version for other 6502s
shouldn't be too much work.

%prep
%autosetup

%build
make %{?_smp_mflags} CC="cc %{optflags}" PREFIX=%{_prefix} datadir=%{_libdir}/cc65 bindir=%{_bindir}

%install
%make_install PREFIX=%{_prefix} datadir=%{_libdir}/cc65 bindir=%{_bindir}
%fdupes -s %{buildroot}

%files
%license LICENSE
%{_bindir}/ar65
%{_bindir}/ca65
%{_bindir}/cc65
%{_bindir}/chrcvt65
%{_bindir}/cl65
%{_bindir}/co65
%{_bindir}/da65
%{_bindir}/grc65
%{_bindir}/ld65
%{_bindir}/od65
%{_bindir}/sim65
%{_bindir}/sp65
%{_libdir}/cc65
%{_datadir}/cc65

%changelog
* Thu Mar 15 2018 mpluskal@suse.com
- Update to version 2.15.0+git.20180312:
  * Added missing ror absolute override.
  * Added missing PCE conio functions.
  * Fix coding style.
  * Add comments.
  * style fixes
  * Switched Apple II output format to AppleSingle.
  * Fix comment typos.
  * Optimize deceaxy.
  * Updated documentation for the reu emd.
  * tweak driver to no more use IRQ
  * also show pressed key, so we can verify keyboard works with the joystick driver
  * add comment on linking, tweak a bit for easier debugging
  * CC65_HOME is gone for quite some time by now.
  * Replaced reu commands with defined constants.
  * Improved reu size detection.
  * Fixed -W cmdline option handling.
  * Made 'wrapped call' code build with VS 2015.
  * Updated from Visual Studio 2013 to Visual Studio 2015.
  * Fixed hex digits case.
  * Joystick drivers don't depend on interrupts anymore.
  * Added 2a03/2a07 and HuC6280 detection.
  * Updated getcpu() function documentation.
  * Made two indirect jumps through the zero-page go through page $20 on the PC-Engine.
  * Update
  * Fixed the 65816/65802 detection.
  * Removed bit opcode, not needed anymore.
  * Added proper 65sc02, 65ce02 and 4510 detection.
  * Shortenned the CBM close() by a byte and a cycle.
  * Small typo
  * Made dio_read(), dio_write(), and dio_write_verify() catch sector number conversion errors.
  * Fixed bugs in the geos-cbm DIO sector-number converter functions.
  * Fixed bugs in geos-cbm's dio_open().
  * Changed the PC-Engine's configuration file, so that the command line can build 8K, 16K, and 32K carts.
  * Update dio.sgml
  * Added GEOS 1.3 and 1.5 detection.
  * Fixed GeOS -> GEOS and added newline to geossym2.inc.
  * Improved GeOS version detection.
  * Added a definition for the CBM610's first CIA chip.
  * Added size_t.
  * Reduced default stack size to a reasonable value.
  * More notes
  * Removed empty notes
  * Added note
  * Requested changes
  * Sorted
  * Added missing function
  * Added missing documentation of header
  * Normalized the definitions of structs in <supervision.h>.
  * Atari: CONSOL port of GTIA is readable and writable.
  * Removed IRQ support from TGI drivers.
  * Marked Apple II EXEHDR segment as optional.
  * Factored out target specific inclusion of target header.
  * Removed ACE header.
  * Harmonized the style of including headers from headers.
  * Removed IRQ support from joystick drivers.
  * Removed IRQ support from joystick drivers.
  * Added missing dummy libref.
  * Added Makefile for recently added linker config test program.
  * Updated AppleCommander URL.
  * Mention the recently added linker configs.
  * Updated AppleCommander URL.
  * Adjust alternative ProDOS 8 I/O buffer allocation module to linker configs.
  * Provide symbole for RAM memory area.
  * Significantly simplified recently added linker config files.
  * Added Apple II linker configs for programs including a hires screen.
  * Moved initcgetc to initcputc
  * atari5200.cfg: fix formatting
  * Fix last change, put display list at beginning of ROM.
  * atari5200: put default display list into its own memory area
  * Added recently published ProDOS version.
  * 65C02 JMP (ind,x) opcode  7C
  * 65C02 version too.
  * Call ParaVirtHooks on JMP (indirect)
  * crt0.s ("none" target): fix initialization of sp variable.
  * Changed the type of a compiler variable that holds either integers or pointers.
  * Shrank Telestrat initcwd.s by 3 bytes.
  * Complain if unsupported flags are provided after -O
  * Added ctype.s to none.lib as suggested by oliverschmidt
  * Fixed unused import and export of none.cfg and none/crt0.s
  * Fixed none/crt0.s to respect none.cfg
  * Fixed none.cfg
  * none.cfg consistency changes
  * cl65 now links against none.lib when using --target none
  * Removed initialization of the stack from none.lib
  * Fixed none.lib missing symbols
  * Added crt0 to none.lib
  * Implemented the requested changes. Moved none to its alphabetic place in the Makefile Reverted all changes to doc/customizing.sgml
  * Revert "Renamed none.lib to no-platform.lib"
  * Renamed none.lib to no-platform.lib
  * Fixed typo.
  * fix spelling
  * Fixed a typo in doc/customizing.sqml
  * Added libray to none target
  * convert to petscii
  * Implementation of getfirstdevice/getnextdevice for Atari.
  * some cleanup
  * updated testprog
  * added peek functions for soft80
  * Added missing "break;" statements to a "switch" statement.
  * Optimizing the stack size
  * oops
  * Update c16.cfg
  * Update c16-32k.cfg
  * Added new config #551
  * Fixed memory config #551
  * Fixed Oric-1 compatibility #550
  * some tweaks to testprog
  * fix cpeeks() for C128 VDC
  * fix cpeeks for CBM610
  * added missing tests
  * copy cpeeks from generic version, this at least makes it work for 40 columns
  * fix petscii conversion for C128
  * PET screen memory is at $8000, not $0800
  * cbm stuff from greggs pull request
  * Removed OPC_EOR_abx duplicate.
  * Removed CBM chartype table.
  * Suppress potential svnversion error output.
  * Fixed the sort order of the function descriptions in the TGI document.
  * Fixed a Table-Of-Contents bug in the TGI document.
  * Update tgi.sgml
  * Update tgi.sgml
  * Update tgi.sgml
  * Splitting of funcref
  * Added missing names for the CIA registers in the C64/C128.
  * Option removed
  * Fix docs for #526
  * Subversion fallback
  * Make use of C library waitvsync().
  * Bumped API version.
  * defined DYN_DRV
  * New API
  * directive removed
  * directive removed
  * New API
  * Update supervision.h
  * Date
  * Fix docs for #453
  * Add files via upload
  * Create supervision-stdjoy.s
  * Creativision documentation enhancements.
  * Made cbm_k_untlk() available.
  * Fix cc65 doc for telestrat target
  * Doc modified
  * Missing declaration
  * Update gamate-stdjoy.s
  * Update gamate-stdjoy.s
  * Correct bits in gamate joystick detection
  * Fix more than 256 codes of same length. Fix all 256 literal codes of same length.
  * Use macro actually defined in cbm_filetype.h.
  * Fix 256 codes of same length
  * Update atmos.sgml
  * Add files via upload
  * Fixed the way that the disassembler looks for the end of a segment.
  * Empty item removed
  * Now mkdir is working
  * Fix doc/telestrat.sgml
  * FIX label for setpixelmode
  * Comment correction
  * Comment correction
  * Remove toascii.s
  * Save/restore jmpvec as it is used by generated code - see g_callind().
  * Replaced three (logically) identical files with a single file.
  * Minor style fix.
  * removing extra spaces
  * toascii.s added, doc updated, tgi_line & tgi_outtext are available
  * comment correction
  * Now setPixel works in TGI.
  * Correction :  authors
  * Optimizing (from Polluks tip)
  * tgi_clear, tgi_init, tgi_done, tgi_getmaxx, tgi_getmaxy are working
  * irq.s added
  * Adding IRQVec
  * clrscr.s switch to text mode
  * I/O identifiers added
  * Adding XSOUT : Send A register to RS232
  * Added commit ca4ed290d5964dbe833224d967d3707e20972278's command-line option to the cl65 document.
  * Correcting comments
  * Adding cgetc
  * Atari: split "setcursor" function out of cgetc.s source file into setcursor.s.
  * cl65: Add support for --all-cdecl
  * optimize
  * telestrat : cgetc add for conio
  * remove FILENAME_MAX
  * Fixing buffer overflow with cwd command (FILENAME_MAX must be at 50 +1 bytes)
  * correcting missing _
  * Fixing bug for cwd
  * Initcwd is now working for telestrat
  * Adding XVARS primitive
  * Correcting missing return line :/
  * correcting some return lines
  * Add some bytes in ZP block in order to able to link with o65 files
  * adding some vars
  * Fixed address
  * conio.h: include 'creativision.h' when compiling for this target.
  * Made <conio.h> include <atari5200.h> when we compile for the Atari 5200 console.
  * Removed an unwanted button mask table from a VIC-20 joystick driver.
  * Made the CBM Pet kbrepeat() work on both 40-column and 80-column machines.
  * Added JOY_FIRE.
  * Reserve space in examples with .res
  * At most 256 bytes will be reserved
  * Removed dysfunctional kbrepeatdelay() and kbrepeatrate().
  * Fixed missing name and semicolon in two device structs.
  * Adjusted to recent driver interface change.
  * Minor style adjustment.
  * Adjusted to recent driver interface change.
  * Adjusted to recent driver interface change.
  * add note on fastcall
  * use fastcall
  * Removed joy_masks array.
  * resolve conflict
  * added documentation for the kbrepeat... functions
  * added prototypes and proposed constants
  * atari5200.inc: fix formatting
  * Removed undesirable empty lines.
  * Made corrections according to review comments
  * Made corrections according to review comments
  * Added documentation for setting the file type for fopen.
  * Documented _filetype and _auxtype
  * Removed 'fire'.
  * Corrected comment formatting
  * Added Variables section comment per convention
  * Moved file type variables to apple2_filetype.h
  * Corrected copyright and moved file type globals
  * Rolled back changes to exclude vim swap files
  * Finished adding all types and comments
  * Added ProDOS file type definitions
  * joy: refactor generic joy_masks array indices and macros
  * make: change uppercase prefix var
  * samples: install to subdirectory
  * pragma: add minimalist message pragma documentation
  * pce: add system specific joy_masks array indices and macros
  * nes: add system specific joy_masks array indices and macros
  * nes: remove semiredundant KEY_ defines
  * pragma: add minimalist message pragma implementation
  * wait for line 0 instead of last line
  * add headers/fix formatting
  * do banking
  * oops
  * implement waitvsync for plus4/c16
  * added prototype to cbm.h
  * fix sgml
  * rename all waitvblank() to waitvsync()
  * pragma: bring pragma_t enum in line with Pragmas struct
  * Made DOS 3.3 IRQ statement more general.
  * Fix coding style.
  * Added the extra dependency file's directory as an order-only prerequisite.
  * Make some arrays const.
  * Added a makefile dependency for the libraries' "extra" files.
  * Added two functions that make it easier to write portable programs for Ohio Scientific computers.
  * use BIT so akku wont get trashed at least in 40 cols mode
  * fixed zp locations provided by polluks :)
  * dont trash akku if possible, use VDC register when in 80column mode
  * Stopped cc65 from putting redundant .segment directives into its Assembly output.
  * fixed some stuff, compiles again :)
  * fixed code a bit so it compiles again :)
  * Added a missing label to some conio cursor movement functions.
  * Small lz4 optimizations
  * Add lz4 doc
  * Mention the optimizations in a comment
  * Use hex immediates
  * Remove _ from internal vars
  * Edit comment style, add second const
  * Added a missing -O configuration.
  * Added a missing -O configuration.
  * Added missing -O configuration.
  * Expand tabs to spaces in lz4.s
  * Add LZ4 decompression support
  * Deprecated commands mentioned
  * Update ar65.sgml
  * Update main.c
  * Verbosity was missing; POSIX operations
  * Update main.c
  * Update list.c
  * Update list.c
  * Update list.c
  * More POSIX.2, staying compatible
  * Use verbosity
  * Oricutron mentioned
  * detectabl > detectable
  * forgot to update comments from earlier #323 rand.s change
  * Added "html" and "info" goals to the top-level Makefile.
  * Added a description of the "-E" command-line option to cl65's document.
  * clean-up
  * expanding macro examples, trying to adhere to style guidelines
  * added missing spaces before braces. added unknown option msg if not given -Wc|l|a when passing options to subprocess
  * ca65 documentation of .define macros, making note that parentheses in ca65 macros are problematic especially when thinking of them as "C style", replacing unclear example with an example showing how accidental parentheses can cause a problem.
  * typo
  * added four escaped tabs to -E Stop after .... description
  * added empty lines and spaces according to olivers comments. Made local functions static.
  * Update test description
  * Added more info to the documentation of "#pragma wrapped-call".
  * Correct comment style
  * Wrapper functions use all registers
  * Add two new trampoline test cases
  * shorter code
  * Adjusted VS project files to commit https://github.com/cc65/cc65/commit/11b01b908d321c39d86de1dd12102eaa6f4053e9
  * Changed section
  * Adjustments in response to latest comments
  * Remove RAM-trampoline array support
  * Rename trampoline to wrappedcall everywhere
  * More tabs to spaces
  * Align with spaces instead of tabs here
  * VIC's kernal does not support CTRL+[
  * Migrate 'encrypted variables' variables to 'repository settings'.
  * Keep GCC from complaining about 'List' may be used uninitialized in this function.
  * Increased GCC optimization level.
  * Optimize the inlined memcpy/memset for the sizes of 128/129.
  * Optimize the inlined strlen.
  * Correct missed doc label
  * Rename pragma trampoline to wrapped-call, value to identifier
  * replaced tabs with spaces which accidently were introduced.
  * According to recent comments on my recent pull request, -Wc checking for -E flag has been removed again. Intead, -E flag has been added to cl65 without need of -Wc. Two functions have been introduced to disable compile, link or both. These function remove assigment repetions to DoAssemble and DoLink for litte overhead, having the maintainability in mind.
  * added -E switch to cl65 for >>stop after the preprocessing stage<<. added compilation and assemblation disable after -Wc -E also with -E beeing part of a comma separated list of arguments
  * test/val/postincdec: Test for the final val value
  * Add explicit postinc/dec testcase
  * Update comments and location checks according to Greg
  * Add fast path for char postdec
  * Add fast path for char postinc
  * Pragma trampoline
  * Add test case
  * Trampoline stack
  * Add IntPtrStack
  * callptr4
  * Document pragma trampoline
  * Removed help for non-existent option.
  * initial import from old sources
  * initial import from old sources
* Fri Apr  7 2017 mpluskal@suse.com
- Update to version 2.15.0+git.20170407:
  * Disallow global variable declarations with an initializer.
  * Global uninitialized variable is only a tentative definition.
  * Issue an error for duplicate global variables.
  * Revert "Disallow global variable declarations with an initializer."
  * Optimization of two string functions (size & speed).
  * Added "strrchr" optimizaion a matching unit test and tiny unit test framework. (Documentation for that will follow later)
  * Fixed indentation
  * Changed the location of unittest.h
  * Added further optimizations and unit tests.
  * Fixed CPU-flag usage which fails on build server?!
  * temporarily disable optimizations altogether until a fine grain control is implemented on Makefile level only disabling the compiler option -Os
  * creativision.inc: add symbolic names for joystick direction values
  * Implement diagonal direction handling in creativision joystick driver.
  * Just some minor style fix.
  * "static int n; int n;" is an error.
  * Add regression test for #204.
  * Add regression tests for duplicate global/static variables detected by the compiler.
  * Add regression tests for duplicate globals with different linkage.
  * Fix line endings (CRLF -> LF) on all affected files.
  * Removed a pointless cc65 command-line option from the samples makefile.
  * Fixed a pointer test again -- but, it's better than in pull request #391.
  * Added .gitattributes to force LF line endings on commit.
  * Made C's sizeof operator work with initialized void variables.
  * few 6502 and some 65SC02 optimizations
  * Creativison changes.
  * Added 65SC02 support for simulator.
  * fixed scrambled semicolon
  * additional fix for scrambled code (sorry)
  * Fixed bug in original sim65 implementation (reason for C&P error in last commit)
  * style changes
  * Removed top blank line.
  * fixed curly brackets for single line scopes
  * Cleaned up test Makefiles.
  * Shortened test subdir names.
  * Run test for the 65C02 code generator / runtime too.
  * Hide stdout of tests returning an exit code.
  * minor style changes
  * Allow to control test Makefile output via QUIET (like libsrc).
  * Fixed addressing error for TSB/TSR and enabled tests again.
  * Added missing line continuation.
  * Revert to recursively expanded var.
  * Fix regression of #pragma bss-name
  * Fixed SGML typo.
  * Fixed SED
  * So far the built-in inlining of several known standard function was always (!) enabled and the option -Os enabled additional, potentially unsafe inlining of some of those functions.
  * Use the more explicit tag style for recently added internal links.
  * Fixed 2 typoes.
  * Minor language update.
  * Removed superfluous final linefeed.
  * Removed workaround.
  * Removed workaround.
  * Removed workaround.
  * Removed workaround.
  * Removed workaround.
  * Fixed the simulations of the stack pointer and the "break" and decimal-mode flags.
  * Bumped version.
  * Just some white space fixes of recently contributed code.
  * Fixed the handling of "while (0) {}".
* Sun Mar  5 2017 mpluskal@suse.com
- Update to version 2.15.0+git.20170304:
  * Initial Creativision Import
  * Added basic frame for new target 'creativision'.
  * fix merge fxxxup
  * Adding files for telemon30
  * Adding ch376.h header, correcting some bugs
  * Correcting some bugs
  * Correcting doc adding telemon 2.4 primitives
  * Adding telemon30 and telemon24 primitives
  * removing ch376.h
  * Revert
  * Merge with current version
  * Fixing old pull request
  * new pull fix
  * Fix
  * Fix
  * Fix
  * Correcting spaces
  * Merge telemon24 and telemon30 into telestrat target. Cleaning, and replace tab to spaces Converting hex lowercase value into uppercase char. Changing := and = when it was needed
  * Correcting comments alignment Correcting an address error in telestrat.inc when cleaning files which broke read.s primitive
  * correcting README.md to add telestrat target
  * Correcting some spaces
  * pce/memcpy.s: remove superfluous comma in comment
  * Cleanups for Creativision.
  * Correcting some code from github comments
  * Correcting return line
  * Correcting alignment
  * Last push for tonight :)
  * Updating doc
  * Fixing telestrat.h
  * Correcting scrsize.s into _scrsize.s
  * gamate, lynx, nes, pce: remove joy_stddrv.s
  * Add initial creativision.sgml, contributed by Stefan Haubenthal.
  * Add Creativision to README.md and html index
  * Reverted 'Used more mundane addressing in some of the instructions in "zlib/inflatemem.s".'
  * intermediate check-in -- creativision joystick driver
  * Rollback for *.vcxproj, telestrat.sgml modified for "don't" instead of "did not" for telemon2.4
  * Optimize inflatemem.
  * Fixed ca65's BRK instruction encoding for the 65816.
  * Add testcode/lib/mouse-test.c. Rename samples/mousetest.c to mousedemo.c.
  * fix indentation
  * Add joystick driver to documentation.
  * Fix joystick driver. Add interruptor support.
  * remove old joystick code
  * Added "telestrat.html" to index.  Sorted "gamate.html".
  * README.md: PC-Engine is a console
  * Improved display list instruction definition for more comfortable use within void data definition.
  * Update atari.sgml
  * Update displaylist.c
  * atari_antic.inc: use "or" instead of "plus" in the usage example
  * adding gotoxy.s
  * Correcting typo
  * adding clrscr.s
  * adding gotox.s gotoy.s wherex.s wherey.s
  * Cleaning
  * Fixed a makefile: "yaccdbg.c" includes "yacc.c". So, yaccdbg must depend on both of them.
  * Fixed a pointer-difference, comparison-with-zero expression.
  * creativision/crt0.s: enable display interrupts in display controller configuration
* Thu Jan 26 2017 mpluskal@suse.com
- Initial package for version cc65-2.15.0+git.20170126
  (inspired by package from home:strik)
